Cleanup/wg init (#260)
* remove wg_init and wg_finalize from functional tests
* Remove wg_init and wg_finalize from examples
* deprecate wg_init/finalize
* Updated docs
* Typo in documentation
---------
Co-authored-by: Yiltan <yiltan@amd.com>
[ROCm/rocshmem commit: 6e7277b544]
Este cometimento está contido em:
cometido por
GitHub
ascendente
192c549d40
cometimento
8837414042
@@ -39,7 +39,6 @@ __global__ void SyncAllTest(int loop, int skip, long long int *start_time,
|
||||
int wg_id = get_flat_grid_id();
|
||||
int wf_id = t_id / wf_size;
|
||||
|
||||
rocshmem_wg_init();
|
||||
|
||||
for (int i = 0; i < loop + skip; i++) {
|
||||
if (hipThreadIdx_x == 0 && i == skip) {
|
||||
@@ -84,7 +83,6 @@ __global__ void SyncAllTest(int loop, int skip, long long int *start_time,
|
||||
end_time[wg_id] = wall_clock64();
|
||||
}
|
||||
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
/******************************************************************************
|
||||
|
||||
Criar uma nova questão referindo esta
Bloquear um utilizador